==> ocstore25_4_23.zip: OcStore/Prgm/data/map/CS_soapcastle_storeroom.lua <==
function E0090()
    MNA()CMU("CS_Vivi")FAI(0)
end
function E0091()
    MNA()CMU("CS_Vivi")FAI(1)
end
function E0092()
    MNA()CMU("CS_Vivi")FAI(2)
end
function E0093()
    MNA()CMU("CS_Vivi")FAI(3)
end
function E0094()
    MNA()CMU("CS_Vivi")FAI(4)
end

function GoSoapCastle()
    if(FLJ("FindSomeFood")) then
        PRI()FAC("jack_normal")MS4("在这个房间里也许能找到食物，")NOD()
        CAT("\n来调查一下吧~")NOD()
    else
        PRI()FAO(3)TRA("CS_soapcastle","E0091",46,22)
    end
end

function SwimSoapCastleTalaRoom()
    PRI()FAO(2)TRA("CS_soapcastle_talaroom","E0090",38,1)
end

function GetFishFeed()
    PRI()
    FAC("jack_normal")MS4("这个好像是铁头的鱼饲料，")NOD()
    CAT("\n咪咪卡多少应该能吃一点吧...")NOD()CLR()
    FAC()CAT("\n我觉得可以~")NOD()CLR()
    FAC("jack_normal")CAT("那我就拿走一包吧...")NOD()CLR()
    ITP("FishFeed")
    GIT("FishFeed")
    SOU("CS_038_get_item")
    DNP("GetFishFeed")
    FLP("GetFishFeed")
    FLS("FindSomeFood")
    FAC()CAT("\n获得了 =鱼饲料= 。")NOD()
    FLP("StoreRoomSavePoint")
    CNP("SavePoint","CS_savepoint",0,0)
end

function PuuPickUpAni()
    KEY()
    MM0()
    PMU(5)
    WAI(32)
    MS2("\n你听到了脚步声...")NOD()CLO()
    WAI(60)
    SNP("CS_puu_animate",7,16,1,"mainLayer","Puu1")
    WAI(60)
    FAC("puu_normal")MS3("\n找红颜料，找红颜料...")NOD()CLO()
    ANP("Puu1","walk",1)
    WAI(128)
    ANP("Puu1","normal",1)
    WAI(32)
    ANP("Puu1","normal",0)
    WAI(32)
    ANP("Puu1","back",0)
    WAI(32)
    ANP("Puu1","back",1)
    WAI(32)
    ANP("Puu1","normal",1)
    WAI(32)
    FAC("puu_normal")MS3("\n找到了！")NOD()CLO()
    ANP("Puu1","walk",1)
    WAI(144)
    ANP("Puu1","back",1)
    WAI(64)
    DNP("RedTank")
    ANP("Puu1","show_tank")
    WAI(32)
    ANP("Puu1","normal",0)
    WAI(32)
    ANP("Puu1","walk",0)
    WAI(128 + 144)
    ANP("Puu1","normal",0)
    WAI(32)
    ANP("Puu1","back",0)
    WAI(32)
    DNP("Puu1")
    RMU(5)
    DNP("PuuPickUpAni")
    FLP("PuuPickUpAni")
end

function ChangeBackMimiga()
    DNP("ChangeBackMimiga")
    FLP("ChangeBackMimiga")
    KEY()
    FAO(0)
    WAI(64)
    SOU("CS_071_little_crash")
    WAI(64)
    SOU("CS_029_teleport")
    WAI(64)
    FLS("FishState")
    SMC()
    local playerNum = GOP();
    --变回咪咪卡
    if(MCN(PLY()) == "CS_mychar_jackfish") then
        SPL(0,"CS_mychar_jack_p1")
        AGP("CS_mychar_jack_p1",false)
        SPL(1,"CS_mychar_santa_p2")
        if(playerNum == 1) then
            AGP("CS_mychar_santa_p2",true)
        end
    else
        SPL(0,"CS_mychar_santa_p2")
        AGP("CS_mychar_santa_p2",false)
        SPL(1,"CS_mychar_jack_p1")
        if(playerNum == 1) then
            AGP("CS_mychar_jack_p1",true)
        end
    end
    DGP("CS_mychar_jackfish_p1")
    DGP("CS_mychar_santafish_p2")
    DGP("CS_mychar_puppyfish_p3")
    --倒在地上
    MOV(28,16,0)
    MOV(29,16,1)
    SLR("CS_mychar_jack_p1")
    AMC("lie")
    SNP("CS_puppy_animate",30,16,1,"mainLayer","Puppy1")
    ANP("Puppy1","normal",0)
    FAI(2)
    WAI(64)
    FAC("jack_><")MS3("\n这一下作为鱼摔的还是有点痛的...")NOD()CLO()
    WAI(32)
    AMC("normal","CS_mychar_santa")
    WAI(64)
    MS3("\n我们变回来了！")NOD()CLO()
    ANP("Puppy1","bark")WAI(16)ANP("Puppy1","bark")WAI(16)
    WAI(64)
    FAC("jack_><")MS3("是嘛...")NOD()
    CAT("\n那可真太好了。")NOD()CLO()
    WAI(32)
    AMC("normal","CS_mychar_jack")
    --SLR("CS_mychar_santa_p2")
    WAI(32)
    AMC("normal",0,"CS_mychar_santa_p2")
    WAI(32)
    AMC("back",0,"CS_mychar_santa_p2")
    AMC("normal",0,"CS_mychar_jack_p1")
    WAI(32)
    MS3("\n这里看起来像是一个仓库...")NOD()CLR()
    AMC("normal",0,"CS_mychar_santa_p2")
    SLR("CS_mychar_jack_p1")
    FAC("jack_normal")MS3("也许我们能在这里找到什么吃的，")NOD()
    CAT("\n来调查看看吧。")NOD()CLO()
    --小狗AI
    SGP("CS_mychar_puppy",30,16,0,"CS_mychar_puppy_p3")
    AGP("CS_mychar_puppy_p3",true)
    DNP("Puppy1")
    FLP("FindSomeFood")
    LIP(1000)
end

function StackedFeed()
    if(FLJ("GetFishFeed")) then
        PRI()
        MS3("这些全是鱼饲料，")NOD()
        CAT("\n看样子怪物们也很喜欢鱼的样子。")NOD()
    else
        PRI()
        MS3("看起来非常重的堆成山的大麻袋，")NOD()
        CAT("\n不知道里面是什么。")NOD()
    end
end

function BlueTank()
    PRI()
    MS3("\n这是一个大型蓝色颜料罐。")NOD()
end

function YellowTank()
    PRI()
    MS3("\n这是一个大型黄色颜料罐。")NOD()
end

==> ocstore25_8_11.zip: OcStore/Prgm/data/map/CS_soapcastle_storeroom.lua <==
function E0090()
    MNA()CMU("CS_Vivi")FAI(0)
end
function E0091()
    MNA()CMU("CS_Vivi")FAI(1)
end
function E0092()
    MNA()CMU("CS_Vivi")FAI(2)
end
function E0093()
    MNA()CMU("CS_Vivi")FAI(3)
end
function E0094()
    MNA()CMU("CS_Vivi")FAI(4)
end

function GoSoapCastle()
    if(FLJ("FindSomeFood")) then
        PRI()FAC("jack_normal")MS4("在这个房间里也许能找到食物，")NOD()
        CAT("\n来调查一下吧~")NOD()
    else
        PRI()FAO(3)TRA("CS_soapcastle","E0091",46,22)
    end
end

function SwimSoapCastleTalaRoom()
    PRI()FAO(2)TRA("CS_soapcastle_talaroom","E0090",38,1)
end

function GetFishFeed()
    PRI()
    FAC("jack_normal")MS4("这个好像是铁头的鱼饲料，")NOD()
    CAT("\n咪咪卡多少应该能吃一点吧...")NOD()CLR()
    FAC()CAT("\n我觉得可以~")NOD()CLR()
    FAC("jack_normal")CAT("那我就拿走一包吧...")NOD()CLR()
    ITP("FishFeed")
    GIT("FishFeed")
    SOU("CS_038_get_item")
    DNP("GetFishFeed")
    FLP("GetFishFeed")
    FLS("FindSomeFood")
    FAC()CAT("\n获得了 =鱼饲料= 。")NOD()
    FLP("StoreRoomSavePoint")
    CNP("SavePoint","CS_savepoint",0,0)
end

function PuuPickUpAni()
    KEY()
    MM0()
    PMU(5)
    WAI(32)
    MS2("\n你听到了脚步声...")NOD()CLO()
    WAI(60)
    SNP("CS_puu_animate",7,16,1,"mainLayer","Puu1")
    WAI(60)
    FAC("puu_normal")MS3("\n找红颜料，找红颜料...")NOD()CLO()
    ANP("Puu1","walk",1)
    WAI(128)
    ANP("Puu1","normal",1)
    WAI(32)
    ANP("Puu1","normal",0)
    WAI(32)
    ANP("Puu1","back",0)
    WAI(32)
    ANP("Puu1","back",1)
    WAI(32)
    ANP("Puu1","normal",1)
    WAI(32)
    FAC("puu_normal")MS3("\n找到了！")NOD()CLO()
    ANP("Puu1","walk",1)
    WAI(144)
    ANP("Puu1","back",1)
    WAI(64)
    DNP("RedTank")
    ANP("Puu1","show_tank")
    WAI(32)
    ANP("Puu1","normal",0)
    WAI(32)
    ANP("Puu1","walk",0)
    WAI(128 + 144)
    ANP("Puu1","normal",0)
    WAI(32)
    ANP("Puu1","back",0)
    WAI(32)
    DNP("Puu1")
    RMU(5)
    DNP("PuuPickUpAni")
    FLP("PuuPickUpAni")
end

function ChangeBackMimiga()
    DNP("ChangeBackMimiga")
    FLP("ChangeBackMimiga")
    KEY()
    FAO(0)
    WAI(64)
    SOU("CS_071_little_crash")
    WAI(64)
    SOU("CS_029_teleport")
    WAI(64)
    FLS("FishState")
    SMC()
    local playerNum = GOP();
    --变回咪咪卡
    if(MCN(PLY()) == "CS_mychar_jackfish") then
        SPL(0,"CS_mychar_jack_p1")
        AGP("CS_mychar_jack_p1",false)
        SPL(1,"CS_mychar_santa_p2")
        if(playerNum == 1) then
            AGP("CS_mychar_santa_p2",true)
        end
    else
        SPL(0,"CS_mychar_santa_p2")
        AGP("CS_mychar_santa_p2",false)
        SPL(1,"CS_mychar_jack_p1")
        if(playerNum == 1) then
            AGP("CS_mychar_jack_p1",true)
        end
    end
    DGP("CS_mychar_jackfish_p1")
    DGP("CS_mychar_santafish_p2")
    DGP("CS_mychar_puppyfish_p3")
    --倒在地上
    MOV(28,16,0)
    MOV(29,16,1)
    SLR("CS_mychar_jack_p1")
    AMC("lie")
    SNP("CS_puppy_animate",30,16,1,"mainLayer","Puppy1")
    ANP("Puppy1","normal",0)
    FAI(2)
    WAI(64)
    FAC("jack_><")MS3("\n这一下作为鱼摔的还是有点痛的...")NOD()CLO()
    WAI(32)
    AMC("normal","CS_mychar_santa")
    WAI(64)
    MS3("\n我们变回来了！")NOD()CLO()
    ANP("Puppy1","bark")WAI(16)ANP("Puppy1","bark")WAI(16)
    WAI(64)
    FAC("jack_><")MS3("是嘛...")NOD()
    CAT("\n那可真太好了。")NOD()CLO()
    WAI(32)
    AMC("normal","CS_mychar_jack")
    --SLR("CS_mychar_santa_p2")
    WAI(32)
    AMC("normal",0,"CS_mychar_santa_p2")
    WAI(32)
    AMC("back",0,"CS_mychar_santa_p2")
    AMC("normal",0,"CS_mychar_jack_p1")
    WAI(32)
    MS3("\n这里看起来像是一个仓库...")NOD()CLR()
    AMC("normal",0,"CS_mychar_santa_p2")
    SLR("CS_mychar_jack_p1")
    FAC("jack_normal")MS3("也许我们能在这里找到什么吃的，")NOD()
    CAT("\n来调查看看吧。")NOD()CLO()
    --小狗AI
    SGP("CS_mychar_puppy",30,16,0,"CS_mychar_puppy_p3")
    AGP("CS_mychar_puppy_p3",true)
    DNP("Puppy1")
    FLP("FindSomeFood")
    LIP(1000)
end

function StackedFeed()
    if(FLJ("HeroBack")) then
        PRI()
        MS3("你的数据库扫描显示")NOD()
        CAT("\n这些是大型食肉鱼饲料。")NOD()
    elseif(FLJ("GetFishFeed")) then
        PRI()
        MS3("这些全是鱼饲料，")NOD()
        CAT("\n看样子怪物们也很喜欢鱼的样子。")NOD()
    else
        PRI()
        MS3("看起来非常重的堆成山的大麻袋，")NOD()
        CAT("\n不知道里面是什么。")NOD()
    end
end

function BlueTank()
    if(FLJ("HeroBack")) then
        PRI()
        MS3("你的数据库扫描显示")
        CAT("\n这是一个大型蓝色丙烯颜料罐")NOD()
    else
        PRI()
        MS3("\n这是一个大型蓝色颜料罐。")NOD()
    end
end

function YellowTank()
    if(FLJ("HeroBack")) then
        PRI()
        MS3("你的数据库扫描显示")
        CAT("\n这是一个大型黄色丙烯颜料罐")NOD()
    else
        PRI()
        MS3("\n这是一个大型黄色颜料罐。")NOD()
    end
end
